@@ -6,27 +6,31 @@ describe Delayed::Backend::ActiveRecord::Job do
 
   describe "configuration" do
     describe "reserve_sql_strategy" do
+      let(:configuration) { Delayed::Backend::ActiveRecord.configuration }
+
       it "allows :optimized_sql" do
-        Delayed::Backend::ActiveRecord.configuration.reserve_sql_strategy = :optimized_sql
-        expect(Delayed::Backend::ActiveRecord.configuration.reserve_sql_strategy).to eq(:optimized_sql)
+        configuration.reserve_sql_strategy = :optimized_sql
+        expect(configuration.reserve_sql_strategy).to eq(:optimized_sql)
       end
 
       it "allows :default_sql" do
-        Delayed::Backend::ActiveRecord.configuration.reserve_sql_strategy = :default_sql
-        expect(Delayed::Backend::ActiveRecord.configuration.reserve_sql_strategy).to eq(:default_sql)
+        configuration.reserve_sql_strategy = :default_sql
+        expect(configuration.reserve_sql_strategy).to eq(:default_sql)
       end
 
       it "raises an argument error on invalid entry" do
-        expect { Delayed::Backend::ActiveRecord.configuration.reserve_sql_strategy = :invald }.to raise_error(ArgumentError)
+        expect { configuration.reserve_sql_strategy = :invald }.to raise_error(ArgumentError)
       end
     end
   end
 
   describe "reserve_with_scope" do
-    let(:worker) { double(name: "worker01", read_ahead: 1) }
-    let(:scope)  { double(limit: limit, where: double(update_all: nil)) }
-    let(:limit)  { double(job: job, update_all: nil) }
-    let(:job)    { double(id: 1) }
+    let(:relation_class) { Delayed::Job.limit(1).class }
+    let(:worker) { instance_double(Delayed::Worker, name: "worker01", read_ahead: 1) }
+    let(:limit) { instance_double(relation_class, update_all: 0) }
+    let(:where) { instance_double(relation_class, update_all: 0) }
+    let(:scope) { instance_double(relation_class, limit: limit, where: where) }
+    let(:job) { instance_double(Delayed::Job, id: 1) }
 
     before do
       allow(Delayed::Backend::ActiveRecord::Job.connection).to receive(:adapter_name).at_least(:once).and_return(dbms)
@@ -40,8 +44,9 @@ describe Delayed::Backend::ActiveRecord::Job do
         let(:dbms) { "MySQL" }
 
         it "uses the optimized sql version" do
-          expect(Delayed::Backend::ActiveRecord::Job).to_not receive(:reserve_with_scope_using_default_sql)
-          Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.now)
+          allow(Delayed::Backend::ActiveRecord::Job).to receive(:reserve_with_scope_using_default_sql)
+          Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.current)
+          expect(Delayed::Backend::ActiveRecord::Job).not_to have_received(:reserve_with_scope_using_default_sql)
         end
       end
 
@@ -49,8 +54,9 @@ describe Delayed::Backend::ActiveRecord::Job do
         let(:dbms) { "OtherDB" }
 
         it "uses the plain sql version" do
-          expect(Delayed::Backend::ActiveRecord::Job).to receive(:reserve_with_scope_using_default_sql).once
-          Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.now)
+          allow(Delayed::Backend::ActiveRecord::Job).to receive(:reserve_with_scope_using_default_sql)
+          Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.current)
+          expect(Delayed::Backend::ActiveRecord::Job).to have_received(:reserve_with_scope_using_default_sql).once
         end
       end
     end
@@ -60,8 +66,9 @@ describe Delayed::Backend::ActiveRecord::Job do
       let(:reserve_sql_strategy) { :default_sql }
 
       it "uses the plain sql version" do
-        expect(Delayed::Backend::ActiveRecord::Job).to receive(:reserve_with_scope_using_default_sql).once
-        Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.now)
+        allow(Delayed::Backend::ActiveRecord::Job).to receive(:reserve_with_scope_using_default_sql)
+        Delayed::Backend::ActiveRecord::Job.reserve_with_scope(scope, worker, Time.current)
+        expect(Delayed::Backend::ActiveRecord::Job).to have_received(:reserve_with_scope_using_default_sql).once
       end
     end
   end
@@ -73,8 +80,8 @@ describe Delayed::Backend::ActiveRecord::Job do
     end
 
     it "returns time in current time zone if set" do
-      Time.zone = "Eastern Time (US & Canada)"
-      expect(%(EST EDT)).to include(Delayed::Job.db_time_now.zone)
+      Time.zone = "Arizona"
+      expect(Delayed::Job.db_time_now.zone).to eq("MST")
     end
 
     it "returns UTC time if that is the AR default" do
@@ -84,16 +91,17 @@ describe Delayed::Backend::ActiveRecord::Job do
     end
 
     it "returns local time if that is the AR default" do
-      Time.zone = "Central Time (US & Canada)"
+      Time.zone = "Arizona"
       ActiveRecord::Base.default_timezone = :local
-      expect(%w(CST CDT)).to include(Delayed::Backend::ActiveRecord::Job.db_time_now.zone)
+      expect(Delayed::Backend::ActiveRecord::Job.db_time_now.zone).to eq("MST")
     end
   end
 
   describe "after_fork" do
     it "calls reconnect on the connection" do
-      expect(ActiveRecord::Base).to receive(:establish_connection)
+      allow(ActiveRecord::Base).to receive(:establish_connection)
       Delayed::Backend::ActiveRecord::Job.after_fork
+      expect(ActiveRecord::Base).to have_received(:establish_connection)
     end
   end
 
@@ -112,12 +120,15 @@ describe Delayed::Backend::ActiveRecord::Job do
       end
 
       after do
-        Delayed::Backend::ActiveRecord::Job.send(:attr_accessible, *Delayed::Backend::ActiveRecord::Job.new.attributes.keys)
+        Delayed::Backend::ActiveRecord::Job.send(
+          :attr_accessible,
+          *Delayed::Backend::ActiveRecord::Job.new.attributes.keys
+        )
       end
 
       it "is still accessible" do
         job = Delayed::Backend::ActiveRecord::Job.enqueue payload_object: EnqueueJobMod.new
-        expect(Delayed::Backend::ActiveRecord::Job.find(job.id).handler).to_not be_blank
+        expect(Delayed::Backend::ActiveRecord::Job.find(job.id).handler).not_to be_blank
       end
     end
   end
